PanelBridge class

Constructors

PanelBridge()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addListener(void listener({required String action, dynamic payload})) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
publish({required String action, dynamic payload}) Future<bool>
removeListener(void listener({required String action, dynamic payload})) bool
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited